from numpy import exp,power,log,ma
def relative_humidity_method_fairall(air_temperature,air_pressure,air_specific_humidity):
    """
    method Fairall
    # computes relative humidity given T,P, & Q
    Args:
        air_temperature (float): in Celius
        air_pressure (float):  [mb]
        air_specific_humidity (float): [kg/kg]
    Returns:
        relative_humidity (float): [%] [0-100]
    """
    es = 6.1121*exp(17.502*air_temperature/(air_temperature+240.97))*(1.0007+3.46e-6*air_pressure)
    em = air_specific_humidity*air_pressure/(0.378*air_specific_humidity+0.622)
    relative_humidity = 100.*em/es
    return relative_humidity

def relative_humidity_from_dew_point_temp(dew,airt):
    """
    method from Bentamy
    Args:
        dew (float): in Celsius
        airt (float): in Celsius
    Returns:
        rh (float): in % [0-0.1]
    """
    Es = 6.11*(power(10.0,(7.5*airt/(273.7+airt))))
    E =  6.11*(power(10.0,(7.5*dew/(273.7+dew))))
    rh = (E/Es)*100. #  Relative humidity
#     if rh>100: rh=100
    rh[rh>100] = 100.
#     if rh<0: rh=0
    rh[rh<0] = 0.
    return rh

def relative_humidity_method_bentamy(air_temperature,air_specific_humdity):
    """
    method Bentamy 
    Args:
        air_temperature (float): in Celius
        air_specific_humdity (float):  [kg/kg]
    Returns:
        relative_humidity (float) :[%] 
    """
    presint = 1013.25
    eps = 0.622
    a = -4.928
    b = 23.55
    c = -2937
    TA = air_temperature+ 273.0
    esatur = (power(TA,a))*(exp((b + (c/TA))*log(10)))
    Qsatur = (eps*esatur)/(presint - (1-eps)*esatur)
    relative_humidity = air_specific_humdity/Qsatur
    return relative_humidity